<?php
/**
 * Custom Order Webhook Extension Registration
 */
\Magento\Framework\Component\ComponentRegistrar::register(
    \Magento\Framework\Component\ComponentRegistrar::MODULE,
    'PortalPeople_OrderWebhook',
    __DIR__
);
